<?php

namespace Service\FileServer;

use Util\SimpleCurl;

class OrganizationHandlerImpl extends APIKeyHandler implements OrganizationHandler {
    const NO_API_KEY_MSG        = "Não foi possível obter uma nova chave de acesso!";
    
    const NEW_API_KEY_ROUTE     = "/organization/create";
    const LIST_ORGS_ROUTE       = "/organizations";
    
    private $fileServerBaseUrl;

    public function __construct($APIKeyToken, $fileServerBaseUrl) {
        parent::__construct($APIKeyToken);
        $this->fileServerBaseUrl = $fileServerBaseUrl; 
    }
    
    public function getAPIKey($nrorg) {
        $secretNrorg = $this->buildSecretOrgName($nrorg);
        $APIKeyToken = $this->getAPIKeyByNrorg($secretNrorg);
        
        if(empty($APIKeyToken)) {
            $APIKeyToken = $this->getNewAPIKey($secretNrorg);
        } 
        
        if(empty($APIKeyToken)) {
            throw new \Exception(self::NO_API_KEY_MSG);
        } 
        
        return $APIKeyToken;
    }
    
    protected function getNewAPIKey($secretNrorg) {
        $url = $this->fileServerBaseUrl . self::NEW_API_KEY_ROUTE;
        $headers = $this->getFileServerCustomHeader();
        $postData = $this->buildNewAPIRequestData($secretNrorg);
        $result = SimpleCurl::post($url, $postData, $headers);
        foreach($result['organization'] as $org) {
            if($org['name'] === $secretNrorg) {
                return $org['apiKey'];
            }
        }
        return $result;
    }

    public function listAPIAllKeys() {
        $headers = $this->getFileServerCustomHeader();
        $url = $this->fileServerBaseUrl . self::LIST_ORGS_ROUTE;
        $result = SimpleCurl::get($url, $headers); 
        return $result['organizations'];
    }
    
    protected function buildSecretOrgName($nrorg) {
        return "tkOrg" . $nrorg;
    }
    
    protected function getAPIKeyByNrorg($secretNrorg) {
        $orgs = $this->listAPIAllKeys();
        foreach($orgs as $org) {
            if($org['name'] === $secretNrorg) {
                return $org['apiKey'];
            }
        }
    }
    
    protected function buildNewAPIRequestData($secretNrorg) {
        return array(
            "requestType" => "Row",
            "row" => array(
                "name" => $secretNrorg,
                "canUpload" => true,
                'isAdmin' => false
            )
        );
    }
}

